@@ -1,6 +1,6 @@
 package App::PerlWatcher::UI::Gtk2::StatusesTreeView;
 {
-  $App::PerlWatcher::UI::Gtk2::StatusesTreeView::VERSION = '0.07_2';
+  $App::PerlWatcher::UI::Gtk2::StatusesTreeView::VERSION = '0.08';
 }
 # ABSTRACT: Widget for displaying statuses in tree-like presentation
 
@@ -215,9 +215,15 @@ sub _constuct_timestamp_column {
             my ( $column, $cell, $model, $iter, $func_data ) = @_;
             my $value = $model->get_value( $iter, 0 );
             my $timestamp = $value->timestamp;
-            my $text = $timestamp ? strftime('%H:%M:%S',localtime $timestamp)
-                                  : q{}
-                                  ;
+            my $text = q{};
+            if ($timestamp) {
+                my @t = localtime $timestamp;
+                my ($sec, $min, $hour) = @t;
+                my $format = ($sec + $min + $hour != 0)
+                    ? '%H:%M:%S'
+                    : '%y/%m/%d';
+                $text = strftime($format, @t);
+            }
             ## $text
             $cell->set( text => $text );
         }
@@ -236,7 +242,7 @@ App::PerlWatcher::UI::Gtk2::StatusesTreeView - Widget for displaying statuses in
 
 =head1 VERSION
 
-version 0.07_2
+version 0.08
 
 =head1 AUTHOR
 
